## Package-specific files:
#### The files within `etc` folder are:

`data_models`: 
- `biothings.model.jsonld`: Base knowledge graph/vocabulary as specified by the [biolink model](https://biolink.github.io/biolink-model/).
- `schema_org.model.jsonld`: Schema vocabulary as specified by [schema.org](https://schema.org/docs/gs.html#schemaorg_types).

`validation_schemas`:
- `class.schema.json`: JSON Schema used for validation against schema.org class definition standard.
- `property.schema.json`: JSON Schema used for validation against schema.org property definition standard.
- `model.schema.json`: JSON Schema used for validation against schema.org standard.